@@ -1,7 +1,7 @@
 package Kafka::Librd;
 use strict;
 use warnings;
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 my $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -17,7 +17,7 @@ Kafka::Librd - bindings for librdkafka
 
 =head1 VERSION
 
-This document describes Kafka::Librd version 0.02
+This document describes Kafka::Librd version 0.03
 
 =head1 SYNOPSIS
 
@@ -136,11 +136,11 @@ support 64 bit integers.
 
 =head2 key
 
-message key
+return message key
 
 =head2 payload
 
-message payload
+return message payload
 
 =cut
 
